Format and parse encoded data.
Modules
- hex_
literal - Hex literal macro implementation.
Macros
- hex
- Macro for converting sequence of string literals containing hex-encoded data into an array of bytes.
Structs
- Hex
- Display/Debug wrapper that renders bytes as lowercase hex without allocating an intermediate String.