Crate commonware_formatting

Crate commonware_formatting 

Format and parse encoded data.

Macros

hex
Converts string literals containing hexadecimal data into a byte array.

Structs

Hex
Display/Debug wrapper that renders bytes as lowercase hex without allocating an intermediate String.

Functions

from_hex
Converts a hexadecimal string to bytes, stripping ASCII whitespace and an optional 0x / 0X prefix.
hex
Converts bytes to a lowercase hexadecimal String.