Crate commonware_formatting
commonware_
formatting
2026.9.0
All Items
Crate Items
Macros
Structs
Functions
Crate
commonware_
formatting
Format and parse encoded data.
Macros

hex
Converts string literals containing hexadecimal data into a byte array.
Structs

Hex
Display/Debug wrapper that renders bytes as lowercase hex without allocating an intermediate
String
.
Functions

from_
hex
Converts a hexadecimal string to bytes, stripping ASCII whitespace and an optional
0x
/
0X
prefix.
hex
Converts bytes to a lowercase hexadecimal
String
.