Crate commonware_formatting

Crate commonware_formatting 

Format and parse encoded data.

Modules

hex_literal
Hex literal macro implementation.

Macros

hex
Macro for converting sequence of string literals containing hex-encoded data into an array of bytes.

Structs

Hex
Display/Debug wrapper that renders bytes as lowercase hex without allocating an intermediate String.

Functions

from_hex
Converts a hexadecimal string to bytes, stripping ASCII whitespace and an optional 0x / 0X prefix.
hex
Converts bytes to a lowercase hexadecimal String.